@@ -1,5 +1,5 @@
 /*
-$Id: mod_webauthldap.c 2236 2005-10-05 05:40:05Z rra $
+$Id: mod_webauthldap.c 2584 2006-06-10 00:14:25Z rra $
 */
 
 #include "httpd.h"
@@ -8,15 +8,22 @@ $Id: mod_webauthldap.c 2236 2005-10-05 05:40:05Z rra $
 #include "ap_config.h"
 #include "apr_signal.h"
 
-#include <string.h>
-#ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#endif
+#include "mod-config.h"
+
 #include <errno.h>
-#include <sys/stat.h>
 #include <stdio.h>
+#include <string.h>
+#include <sys/stat.h>
+#ifdef HAVE_UNISTD_H
+# include <unistd.h>
+#endif
 
 #include <krb5.h>
+#ifdef HAVE_ET_COM_ERR_H
+# include <et/com_err.h>
+#else
+# include <com_err.h>
+#endif
 #include <ldap.h>
 
 #include "mod_webauthldap.h"
@@ -76,7 +83,7 @@ int sasl_interact_stub(LDAP *ld,
 static const char *
 cfg_str(cmd_parms * cmd, void *mconf, const char *arg)
 {
-    int e = (int)cmd->info;
+    intptr_t e = (intptr_t) cmd->info;
     char *error_str = NULL;
     /* MWAL_DCONF *dconf = (MWAL_DCONF *) mconf; */
 
@@ -114,7 +121,7 @@ cfg_str(cmd_parms * cmd, void *mconf, const char *arg)
         error_str =
             apr_psprintf(cmd->pool,
                          "Invalid value cmd->info(%d) for directive %s",
-                         e, cmd->directive->directive);
+                         (int) e, cmd->directive->directive);
         break;
 
     }
@@ -127,7 +134,7 @@ cfg_str(cmd_parms * cmd, void *mconf, const char *arg)
 static const char *
 cfg_flag(cmd_parms * cmd, void *mconfig, int flag)
 {
-    int e = (int)cmd->info;
+    intptr_t e = (intptr_t) cmd->info;
     char *error_str = NULL;
     /* MWAL_DCONF *dconf = (MWAL_DCONF *) mconfig; */
 
@@ -149,7 +156,7 @@ cfg_flag(cmd_parms * cmd, void *mconfig, int flag)
         error_str =
             apr_psprintf(cmd->pool,
                          "Invalid value cmd->info(%d) for directive %s",
-                         e, cmd->directive->directive);
+                         (int) e, cmd->directive->directive);
         break;
 
     }
@@ -162,7 +169,7 @@ cfg_flag(cmd_parms * cmd, void *mconfig, int flag)
 static const char *
 cfg_multistr(cmd_parms * cmd, void *mconf, const char *arg)
 {
-    int e = (int)cmd->info;
+    intptr_t e = (intptr_t) cmd->info;
     char *error_str = NULL;
     MWAL_DCONF *dconf = (MWAL_DCONF *) mconf;
     char** attrib;
@@ -181,7 +188,7 @@ cfg_multistr(cmd_parms * cmd, void *mconf, const char *arg)
         error_str =
             apr_psprintf(cmd->pool,
                          "Invalid value cmd->info(%d) for directive %s",
-                         e, cmd->directive->directive);
+                         (int) e, cmd->directive->directive);
         break;
 
     }
@@ -191,7 +198,7 @@ cfg_multistr(cmd_parms * cmd, void *mconf, const char *arg)
 static const char *
 cfg_take12(cmd_parms *cmd, void *mconfig, const char *w1, const char *w2)
 {
-    int e = (int)cmd->info;
+    intptr_t e = (intptr_t) cmd->info;
     char *error_str = NULL;
 
     MWAL_SCONF *sconf = (MWAL_SCONF *)
@@ -206,8 +213,8 @@ cfg_take12(cmd_parms *cmd, void *mconfig, const char *w1, const char *w2)
         default:
             error_str = 
                 apr_psprintf(cmd->pool,
-                             "Invalid value cmd->info(%d) for directive %s", e,
-                             cmd->directive->directive);
+                             "Invalid value cmd->info(%d) for directive %s",
+                             (int) e, cmd->directive->directive);
             break;
     }
     return error_str;
@@ -675,16 +682,25 @@ webauthldap_bind(MWAL_LDAP_CTXT* lc, int print_local_error)
 {
     int rc;
     MWAL_SASL_DEFAULTS *defaults;
+    LDAPURLDesc url;
+    char *ldapuri;
 
     /* Initialize the connection */
-    lc->ld = ldap_init(lc->sconf->host, lc->port);
-
-    if (lc->ld == NULL) {
+    memset(&url, 0, sizeof(url));
+    url.lud_scheme = "ldap";
+    url.lud_host = lc->sconf->host;
+    url.lud_port = lc->port;
+    url.lud_scope = LDAP_SCOPE_DEFAULT;
+    ldapuri = ldap_url_desc2str(&url);
+    rc = ldap_initialize(&lc->ld, ldapuri);
+    if (rc != LDAP_SUCCESS) {
         ap_log_error(APLOG_MARK, APLOG_ERR, 0, lc->r->server, 
-                     "webauthldap(%s): ldap_init failure ld is NULL", 
-                     lc->r->user);
+                     "webauthldap(%s): ldap_initialize failed with URL %s", 
+                     lc->r->user, ldapuri);
+        free(ldapuri);
         return -1;
     }
+    free(ldapuri);
 
     /* Set to no referrals */
     if (ldap_set_option(lc->ld, LDAP_OPT_REFERRALS, LDAP_OPT_OFF)
@@ -931,7 +947,7 @@ webauthldap_returnconn(MWAL_LDAP_CTXT* lc)
     apr_thread_mutex_unlock(lc->sconf->ldmutex); /****** UNLOCKING! ********/
 
     if (newld == NULL) {
-        ldap_unbind(lc->ld); 
+        ldap_unbind_ext(lc->ld, NULL, NULL); 
     }
 
 }
@@ -1489,7 +1505,7 @@ auth_checker_hook(request_rec * r)
             ap_log_error(APLOG_MARK, APLOG_INFO, 0, lc->r->server,
                          "webauthldap(%s): unbinding the expired connection",
                              lc->r->user);
-        ldap_unbind(lc->ld);
+        ldap_unbind_ext(lc->ld, NULL, NULL);
         lc->ld = NULL;
 #ifdef SIGPIPE
         apr_signal(SIGPIPE, old_signal);
