@@ -1,15 +1,8 @@
-
 #include "config.h"
 
 #include <stdio.h>
-
-#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
-#endif
-
-#ifdef HAVE_STRING_H
 #include <string.h>
-#endif
 
 #include "webauth.h"
 #include "webauthtest.h"
@@ -18,7 +11,7 @@
 
 int main(int argc, char *argv[])
 {
-    unsigned char orig_buffer[BUFSIZE];
+    char orig_buffer[BUFSIZE];
     int s;
     TEST_VARS;
 
